/*
 * Board initialize code for TANBAC Evaluation board TB0229.
 *
 * (C) Masami Komiya <mkomiya@sonare.it> 2004
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2, or (at
 * your option) any later version.
 */

#include <common.h>
#include <command.h>
#include <asm/addrspace.h>
#include <pci.h>

#ifdef CFG_TB0287_MINI_ITX
#if (CONFIG_COMMANDS & CFG_CMD_JFFS2) && defined(CFG_JFFS_CUSTOM_PART)
#include <jffs2/jffs2.h>
#define JFFS_CUSTOM_PART_NUM	1
static struct part_info part[JFFS_CUSTOM_PART_NUM];
#endif
#endif	/* CFG_TB0287_MINI_ITX */

unsigned long mips_io_port_base = 0;

#if defined(CONFIG_PCI)
static struct pci_controller hose;

#ifdef CFG_TB0287_MINI_ITX
static struct pci_device_id supported[] = {
	{0x1095, 0x0680},
	{}
};

extern ulong ide_bus_offset[CFG_IDE_MAXBUS];
#endif	/* CFG_TB0287_MINI_ITX */

extern void init_vr4131_pci(struct pci_controller*);

void pci_init_board (void)
{
#ifdef CFG_TB0287_MINI_ITX
	pci_dev_t devno;
	u32 iobase;
#endif	/* CFG_TB0287_MINI_ITX */

	init_vr4131_pci(&hose);

#ifdef CFG_TB0287_MINI_ITX
	if ((devno = pci_find_devices(supported, 0)) >= 0) {
	  pci_read_config_dword(devno, PCI_BASE_ADDRESS_0, &iobase);
	  iobase &= ~0x3;

	  printf ("IDE:SIL0680 @0x%x\n", iobase);

	  ide_bus_offset[0] = KSEG1ADDR(iobase + 0x16000000 - 0x00000000);
#if CFG_IDE_MAXBUS > 1
	  pci_read_config_dword(devno, PCI_BASE_ADDRESS_2, &iobase);
	  iobase &= ~0x3;
	  ide_bus_offset[1] = KSEG1ADDR(iobase + 0x16000000 - 0x00000000);
#endif
	  /* enable mmaped I/O */
	  /* pci_write_config_byte(devno, PCI_CLASS_PROG, 5 ); */
	  pci_write_config_byte(devno, PCI_LATENCY_TIMER, 0x80);
	  ide_init();
	}
#endif	/* CFG_TB0287_MINI_ITX */
}
#endif


long int initdram(int board_type)
{
	return get_ram_size ((volatile long *)CFG_SDRAM_BASE, 0x8000000);
}


int checkboard (void)
{
	printf("Board: TANBAC TB0229 ");
	printf("(CPU Speed %d MHz)\n", (int)CPU_CLOCK_RATE/1000000);

	return 0;
}

#ifdef CFG_TB0287_MINI_ITX
#if (CONFIG_COMMANDS & CFG_CMD_JFFS2) && defined(CFG_JFFS_CUSTOM_PART)
struct part_info*
jffs2_part_info(int part_num)
{
        if (0 <= part_num && part_num < JFFS_CUSTOM_PART_NUM){
                if(part[part_num].usr_priv==(void*)1)
                        return &part[part_num];
                memset(&part[part_num], 0, sizeof(part[0]));
		switch ( part_num ) {
		case 0:
                	part[part_num].offset=(char*)0xBFC60000;
                	part[part_num].size= 0xC0000000 - 0xBFC60000;
			break;
		}
                /* Mark the struct as ready */
                part[part_num].usr_priv=(void*)1;
                return &part;
        }
        return 0;
}
#endif
#endif	/* CFG_TB0287_MINI_ITX */
