/*
 *  Memory sub-system initialization code for TANBAC TB0290 Board.
 *
 *  Copyright (c) 2005  Hiroyasu Nakatsuka
 *  Copyright (c) 2005  Susumu Morishita
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2, or (at
 * your option) any later version.
 */

#include <config.h>
#include <version.h>
#include <asm/regdef.h>
#include <asm/mipsregs.h>
	
	.set	noreorder
	.globl  memsetup
	.ent	memsetup
memsetup:

	/* Initialize LocalBus */
	li	t0, 0xb8800000
	li	t1, 0x01001801
	sw	t1, 0x828(t0) 		# CS6
	sw	t1, 0x824(t0)		# CS5
	sw	t1, 0x820(t0)		# CS4
	sw	t1, 0x818(t0)		# CS2
	sw	t1, 0x814(t0)		# CS1

	li	t1, 0x09000001
	sw	t1, 0x81c(t0)		# CS3

	/* sdramc base address */
	la	t0, 0xb8000000
	/* SDINITCNT */
	li	t1, 0x81050f82
	sw	t1, 0x248(t0)

	/* SDREFCYC */
	li	t1, 0x00000600
	sw	t1, 0x220(t0)

	/* SDTYPE */
	li	t1, 0x00000618
	sw	t1, 0x200(t0)


	/* SDCNT(72bit no-ECC, ARENA=0) */
	li	t1, 0x14001418

	la	t2, 0xBFFFF000		# TANBAC config addr
	lw	t2, 0(t2)
	xor	t2, t2, 0x54420001	# TANBAC config MAGIC
	beq     t2, zero, valid_config
	nop
	j	no_ecc
	xor	t2, t2, t2
valid_config:	
	li	t2, 0xBFFFF154		# TANBAC ECC config
	lw	t2, 0(t2)
        andi    t2, t2, 0x1
	beq     t2, zero, no_ecc
	nop
	/* SDCNT(72bit ECC, ARENA=0) */
	li	t1, 0x14033418
no_ecc:
	sw	t1, 0x218(t0)
	
	/* SDTIMING */
	li	t1, 0x55486892
	sw	t1, 0x208(t0)

	/* SDMODE */
	li	t1, 0x4000002a
	sw	t1, 0x210(t0)

	/* SDCNT(72bit no-ECC, ARENA=1) */
	li	t1, 0x1400141c

	beq     t2, zero, no_ecc2
	nop
	/* SDCNT(72bit ECC, ARENA=1) */
	li	t1, 0x1403341c
no_ecc2:
	sw	t1, 0x218(t0)

	/* Clear TLB */
	li	t0, 63
	li	t1, 0xa0000000				# default : unmap area
	li	t2, 0x00002000				# entry hi incriment value = +8K

	mtc0	zero, CP0_ENTRYLO0		# CP0_EntryLo0 = 0
	nop
	mtc0	zero, CP0_ENTRYLO1		# CP0_EntryLo1 = 0
	nop
	mtc0	zero, CP0_PAGEMASK		# CP0_MASK = 0
	nop
	mtc0	zero, CP0_FRAMEMASK		# CP0 Frame mask = 0
	nop
1:
	mtc0	t1, CP0_ENTRYHI			# CP0_EntryHi = 0xa0000000+(63-index)
	nop
	mtc0	t0, CP0_INDEX			# CP0_EntryIndex
	nop
	tlbwi
	nop
	addu	t1, t2, t1				# incriment Entry Hi
	addiu	t0, t0, -1
	bne		t0, zero, 1b
	nop

	/* TLB0 : 0xE000_0000 -> 0xF_F000_0000 (for normal mode) */
	mtc0	zero, CP0_INDEX			# CP0_EntryIndex
	li	t0, 0x3FC00017			# PFN=F_F000_0000, c=2,	v=d=1
	mtc0	t0, CP0_ENTRYLO0		# CP0_EntryLo0
	nop
	mtc0	t0, CP0_ENTRYLO1		# CP0_EntryLo1
	nop
	li	t0, 0x1FFFE000			# 256MB/page
	mtc0	t0, CP0_PAGEMASK		# CP0_MASK
	nop
	li	t0, 0xE0000000			# VPN=E000_0000
	mtc0	t0, CP0_ENTRYHI			# CP0_EntryHi
	nop
	tlbwi
	nop

	/* TLB1 : 0x0000_0000 -> 0x0_0000_0000 (for normal mode) */
	li	t0, 0x1
	mtc0	t0, CP0_INDEX			# CP0_EntryIndex
	li	t0, 0x00000017			# PFN=0_0000_0000, c=2,	v=d=1
	mtc0	t0, CP0_ENTRYLO0		# CP0_EntryLo0
	li	t0, 0x01000017			# PFN=0_4000_0000, c=2,	v=d=1
	mtc0	t0, CP0_ENTRYLO1		# CP0_EntryLo1
	nop
	li	t0, 0x7FFFE000			# 1GB/page
	mtc0	t0, CP0_PAGEMASK		# CP0_MASK
	nop
	li	t0, 0x00000000			# VPN=0000_0000
	mtc0	t0, CP0_ENTRYHI			# CP0_EntryHi
	nop
	tlbwi
	nop

	j       ra
	nop
	.end  memsetup

	.set	noreorder
	.globl  eccinit
	.ent	eccinit
/* arg0 : dramsize */

eccinit:
	la	t3, return_from64
	la	t0, ecc_clear
	li	t1, 0x0fffffff
	and	t0, t1, t0
	li	t1, 0xE0000000
	or	t0, t1, t0
	jr	t0
	
ecc_clear:
/* change from regacy mode to normal mode */		
	lui	t0, 0xE800
	lw	t1, 0x0(t0)
	ori	t1, t1, 0x0001
	sw	t1, 0x0(t0)
	nop
	nop
	nop
/* mask dram ecc interrupt */
	
	li	t0, 0xE8800B46
	li	t1, 0xfff3
	sh	t1, 0x0(t0)
	
/* CLEAN ECC setup DRAM */
	li	t0, 0x00000000
	move	t2, a0 /* DRAM size */
	or	t1, t0, t2
	li	t2, CFG_INIT_SP_OFFSET
	addu	t0, t0, t2
	li	t2, CFG_L2CACHELINE_SIZE
dram_clear_loop:
	sb	zero, 0x0(t0)
	bne	t1, t0, dram_clear_loop
	addu	t0, t0, t2
	
/* change from normal mode to regacy mode */
	lui	t0, 0xE800
	lw	t1, 0x0(t0)
	andi	t1, t1, 0x0002
	sw	t1, 0x0(t0)
	nop
	nop
	nop
	jr	t3
	nop
	
return_from64:	
	li	t0, 0xb8000000	# Clear Err Syndrome registers
	sw	zero, 0x230(t0)
	sw	zero, 0x238(t0)
	sw	zero, 0x240(t0)
	li	t0, 0xb8800b40	# Clear NMI (sdram ECC Error bits) 
	ori	t1, zero, 0xc
	sh	t1, 0x0(t0)

	/* TLB map : 0xE000_0000 -> 0x1_0000_0000 (for PCI-X Mem) */
	li	t0, 0x04000017			# PFN=1_0000_0000,	c=2,	v=d=1
	mtc0	t0, CP0_ENTRYLO0		# CP0_EntryLo0
	nop
	mtc0	t0, CP0_ENTRYLO1		# CP0_EntryLo1
	nop
	li	t0, 0x1FFFE000			# 256MB/page
	mtc0	t0, CP0_PAGEMASK		# CP0_MASK
	nop
	mtc0	zero, CP0_FRAMEMASK		# CP0 Frame mask = 0
	nop
	li	t0, 0xE0000000			# VPN=E000_0000
	mtc0	t0, CP0_ENTRYHI			# CP0_EntryHi
	nop
	mtc0	zero, CP0_INDEX			# CP0_EntryIndex
	nop
	tlbwi
	nop

	/* TLB1 : TLB off */
	li	t0, 0x1
	mtc0	t0, CP0_INDEX			# CP0_EntryIndex
	mtc0	zero, CP0_ENTRYLO0		# CP0_EntryLo0
	mtc0	zero, CP0_ENTRYLO1		# CP0_EntryLo1
	nop
	mtc0	zero, CP0_PAGEMASK		# CP0_MASK
	nop
	li	t0, 0xa007c000			# VPN=a000_2000
	mtc0	t0, CP0_ENTRYHI			# CP0_EntryHi
	nop
	tlbwi
	nop
	
	j       ra
	nop
	.end  eccinit
	
	
	.set	noreorder
	.globl  eccinit_min
	.ent	eccinit_min
eccinit_min:
/* mask dram ecc interrupt */
	li	t0, 0xE8800B46
	li	t1, 0xfff3
	sh	t1, 0x0(t0)

/* CLEAN ECC setup DRAM */
	li	t0, CFG_SDRAM_BASE
	li	t1, CFG_SDRAM_BASE + CFG_INIT_SP_OFFSET
	li	t2, CFG_L2CACHELINE_SIZE
dram_clear_loop_min:
	sb	zero, 0x0(t0)
	bne	t1, t0, dram_clear_loop_min
	addu	t0, t0, t2
	
	li	t0, 0xb8000000	# Clear Err Syndrome registers
	sw	zero, 0x230(t0)
	sw	zero, 0x238(t0)
	sw	zero, 0x240(t0)
	li	t0, 0xb8800b40	# Clear NMI (sdram ECC Error bits) 
	ori	t1, zero, 0xc
	sh	t1, 0x0(t0)

	j       ra
	nop
	.end  eccinit_min
	
	
