/*
 *
 * BRIEF MODULE DESCRIPTION
 *	Include file for NEC Electronics Corp, Ywing CPU.
 *
 * Copyright 2005 NEC Electronics Inc.
 * Author: Hiroyasu Nakatsuka.
 *
 *  This program is free software; you can redistribute  it and/or modify it
 *  under  the terms of  the GNU General  Public License as published by the
 *  Free Software Foundation;  either version 2 of the  License, or (at your
 *  option) any later version.
 *
 *  THIS  SOFTWARE  IS PROVIDED   ``AS  IS'' AND   ANY  EXPRESS OR IMPLIED
 *  WARRANTIES,   INCLUDING, BUT NOT  LIMITED  TO, THE IMPLIED WARRANTIES OF
 *  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN
 *  NO  EVENT  SHALL   THE AUTHOR  BE    LIABLE FOR ANY   DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 *  NOT LIMITED   TO, PROCUREMENT OF  SUBSTITUTE GOODS  OR SERVICES; LOSS OF
 *  USE, DATA,  OR PROFITS; OR  BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 *  ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 *  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *  You should have received a copy of the  GNU General Public License along
 *  with this program; if not, write  to the Free Software Foundation, Inc.,
 *  675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef _YWING_H_
#define _YWING_H_

#ifndef __ASSEMBLY__
/* cpu pipeline flush */
void static inline __ydelay(unsigned long loops)
{
	__asm__ volatile (
		".set\tnoreorder\n"
		"1:\tbnez\t%0,1b\n\t"
		"subu\t%0,1\n\t"
		".set\treorder"
		:"=r" (loops)
		:"0" (loops));
}

void static inline y_sync(void)
{
	__asm__ volatile ("sync");
}

void static inline y_sync_udelay(int us)
{
	__asm__ volatile ("sync");
	udelay(us);
}

void static inline y_writeb(u8 val, int reg)
{
	*(volatile u8 *)(reg) = val;
}

void static inline y_writeh(u16 val, int reg)
{
	*(volatile u16 *)(reg) = val;
}

void static inline y_writew(u32 val, int reg)
{
	*(volatile u32 *)(reg) = val;
}

static inline u8 y_readb(unsigned long port)
{
	return (*(volatile u8 *)port);
}

static inline u16 y_readh(unsigned long port)
{
	return (*(volatile u16 *)port);
}

static inline u32 y_readw(unsigned long port)
{
	return (*(volatile u32 *)port);
}

void static inline y_reseth(u16 val1, unsigned delay, u16 val2, int reg)
{
	*(volatile u16 *)(reg) = val1;
	__ydelay(delay);
	*(volatile u16 *)(reg) = val2;
}

void static inline y_resetw(u32 val1, unsigned delay, u32 val2, volatile u32 *reg)
{
	*(volatile u32 *)(reg) = val1;
	__ydelay(delay);
	*(volatile u32 *)(reg) = val2;
}

/* These next three functions should be a generic part of the MIPS
 * kernel (with the 'y_' removed from the name) and selected for
 * processors that support the instructions.
 * Taken from PPC tree.  -- Dan
 */
/* Return the bit position of the most significant 1 bit in a word */
static __inline__ int __ilog2(unsigned int x)
{
	int lz;

	asm volatile (
		".set\tnoreorder\n\t"
		".set\tnoat\n\t"
		".set\tmips32\n\t"
		"clz\t%0,%1\n\t"
		".set\tmips0\n\t"
		".set\tat\n\t"
		".set\treorder"
		: "=r" (lz)
		: "r" (x));

	return 31 - lz;
}

static __inline__ int y_ffz(unsigned int x)
{
	if ((x = ~x) == 0)
		return 32;
	return __ilog2(x & -x);
}

/*
 * ffs: find first bit set. This is defined the same way as
 * the libc and compiler builtin ffs routines, therefore
 * differs in spirit from the above ffz (man ffs).
 */
static __inline__ int y_ffs(int x)
{
	return __ilog2(x & -x) + 1;
}

#endif /* !ASSEMBLY */

#ifdef CONFIG_PM
/* no CP0 timer irq */
#define ALLINTS (IE_IRQ0 | IE_IRQ1 | IE_IRQ2 | IE_IRQ3 | IE_IRQ4)
#else
#define ALLINTS (IE_IRQ0 | IE_IRQ1 | IE_IRQ2 | IE_IRQ3 | IE_IRQ4 | IE_IRQ5)
#endif

#define CP0_IWATCHLO		$18,1
#define CP0_DEBUG		$23

/**************************************************/
/*   SDRAM Controller                             */
/**************************************************/
#define SDTYPE                0xB8000200
#define SDTIMING              0xB8000208
#define SDMODE                0xB8000210
#define SDCNT                 0xB8000218
#define SDREFCYC              0xB8000220
#define SDREFCOUNT            0xB8000228
#define SDERRADDR             0xB8000230
#define SDERRSYNHI            0xB8000238
#define SDERRSYNLO            0xB8000240
#define SDINITCNT             0xB8000248
#define SDERRINSHI            0xB8000250
#define SDERRINSLO            0xB8000258

/**************************************************/
/*   L2 Cache Controller                          */
/**************************************************/
#define SCALLOCCNT            0xB8000048
#define SCIDXSTTAG            0xB8000050
#define SCIDXLDTAG            0xB8000058
#define SCIDXWBINV            0xB8000060
#define SCHITWBINV            0xB8000068
#define SCTAG                 0xB8000100
#define SCECC                 0xB8000108
#define SCLRU                 0xB8000110
#define SCWRCNT               0xB8000118

/**************************************************/
/*   GPIO                                         */
/**************************************************/
#define GPIO_SEL              0xB8800900
#define GPIO_IOSEL1           0xB8800910
#define GPIO_IOSEL2           0xB8800912
#define GPIO_IOSEL3           0xB8800914
#define GPIO_IOSEL4           0xB8800916
#define GPIO_IOSEL5           0xB8800918
#define GPIO_DATA1            0xB8800920
#define GPIO_DATA2            0xB8800922
#define GPIO_DATA3            0xB8800924
#define GPIO_DATA4            0xB8800926
#define GPIO_DATA5            0xB8800928

/**************************************************/
/*   Interrupt Controller                         */
/**************************************************/
#define CH1_LEVEL             0xB8800B00
#define CH2_LEVEL             0xB8800B02
#define CH3_LEVEL             0xB8800B04
#define CH4_LEVEL             0xB8800B06
#define CH5_LEVEL             0xB8800B08
#define CH6_LEVEL             0xB8800B0A
#define CH7_LEVEL             0xB8800B0C
#define CH8_LEVEL             0xB8800B0E
#define CH9_LEVEL             0xB8800B10
#define CH10_LEVEL            0xB8800B12
#define CH11_LEVEL            0xB8800B14
#define CH12_LEVEL            0xB8800B16
#define CH13_LEVEL            0xB8800B18
#define CH14_LEVEL            0xB8800B1A
#define CH15_LEVEL            0xB8800B1C
#define CH16_LEVEL            0xB8800B1E

#define INT_CLR               0xB8800B20
#define INT_SET               0xB8800B22
#define INT_PENDING           0xB8800B24
#define LEVEL_EDGE            0xB8800B26
#define INT_MASK              0xB8800B28
#define LEVEL_MASK            0xB8800B2A
#define INT_ACK               0xB8800B2C
#define INT_VECTOR            0xB8800B2E
#define INT_STATUS            0xB8800B30
#define INT_ACT_LV            0xB8800B32

#define NMI_CLR               0xB8800B40
#define NMI_SET               0xB8800B42
#define NMI_PENDING           0xB8800B44
#define NMI_MASK              0xB8800B46
#define OUT_SEL               0xB8800B48
#define NMI_STATUS            0xB8800B4A

/* Interrupt Numbers */
#define INTC_NMI_INT             0x0001
#define INTC_PCIX_INT            0x0002
#define INTC_ETH_INT             0x0004
#define INTC_LBIF_INT            0x0008
#define INTC_UART_INT            0x0010
#define INTC_TIMER0_3_INT        0x0020
#define INTC_TIMER4_7_INT        0x0040
#define INTC_TIMER8_INT          0x0080
#define INTC_INTP0_INT           0x0100
#define INTC_INTP1_INT           0x0200
#define INTC_INTP2_INT           0x0400
#define INTC_INTP3_INT           0x0800
#define INTC_INTP4_INT           0x1000
#define INTC_INTP5_INT           0x2000
#define INTC_INTP6_INT           0x4000
#define INYC_INTP7_INT           0x8000

/**************************************************/
/*   Ethernet Controllers (Candy)                 */
/**************************************************/
#define ETH0_BASE          0xB8802000
#define ETH1_BASE          0xB8802400

/* Ethernet register offset */
#define	MACC1		0x000
#define MACC2		0x004
#define Eth_IPGT	0x008
#define	IPGR		0x00c
#define	CLRT		0x010
#define	LMAX		0x014
#define	LSA2		0x054
#define	LSA1		0x058
#define	PTVR		0x05c
#define	Eth_VLTP		0x064
#define MIIC		0x080
#define	MCMD		0x094
#define	MADR		0x098
#define	MWTD		0x09c
#define	MRDD		0x0a0
#define	MIND		0x0a4
#define AFR		    0x0c8
#define HT1		    0x0cc
#define	HT2		    0x0d0
#define	CAR1		0x0dc
#define	CAR2		0x0e0
#define	CAM1		0x130
#define	CAM2		0x134

#define	RBYTC		0x140
#define	RPKTC		0x144
#define	RFCSC		0x148
#define	RMCAC		0x14c
#define	RBCAC		0x150
#define	RXCFC		0x154
#define	RXPFC		0x158
#define	RXUOC		0x15c
#define	RXLNC		0x160
#define	RFLRC		0x164

#define	RCDEC		0x168
#define	RFCRC		0x17c
#define	RUNDC		0x170
#define	ROVRC		0x174
#define	RFRGC		0x178
#define	RJBRC		0x17c
#define	R64C		0x180
#define	R127C		0x184
#define	R255C		0x188
#define	R511C		0x18c
#define	R1KC		0x190
#define	RMAXC		0x194
#define	RVBTC		0x198

#define TBYTC		0x1c0
#define TPKTC		0x1c4
#define TFCSC		0x1c8
#define TMCAC		0x1cc
#define TBCAC		0x1d0
#define TUCAC		0x1d4
#define TXPFC		0x1d8
#define TDFRC		0x1dc
#define TXDFC		0x1e0
#define TSCLC		0x1e4
#define TMCLC		0x1e8
#define TLCLC		0x1ec
#define TXCLC		0x1f0
#define TNCLC		0x1f4
#define TCSEC		0x1f8
#define TIMEC		0x1fc

#define	XMT_CFGR 	0x200
#define	XMT_DPR	 	0x214

#define	RCV_CFGR 	0x218
#define	RCV_DPR		0x22c
#define	RCV_PDR		0x230
#define RCV_PDR1 	0x230

#define	XMT_CTLR 	0x204
#define	XMT_DR		0x208
#define	XMT_STR		0x20c
#define	XMT_APR		0x210

#define	RCV_CTLR 	0x21c
#define	RCV_DR		0x220
#define	RCV_STR		0x224
#define	RCV_APR		0x228
#define	FMSMON		0x25c
#define	CCR		    0x234
#define	ISR		    0x238
#define	MSR		    0x23c
#define	DMA_RST		0x250
#define	RCV_MAC_RST	0x254
#define	XMT_MAC_RST	0x258

/**************************************************/
/*   GbitEthernet Controllers (Arcadia)           */
/**************************************************/
#define GETH0_BASE	0xb8804000
#define GETH1_BASE	0xb8805000

// Gbit Ethernet register offset
#define	GMACC1		0x00
#define GMACC2		0x08
#define GIPGIFG		0x10
#define	GIPGR		0x18
#define	GLMAX		0x20

#define GMIIC		0x40
#define	GMCMD		0x48
#define	GMADR		0x50
#define	GMWTD		0x58
#define	GMSTA		0x60
#define	GMIND		0x68
#define	GPHYC		0x70

#define	GLSA1		0x80
#define	GLSA2		0x88

#define	GCAR1		0xe0
#define	GCAR2		0xe8
#define	GCAM1		0xf0
#define	GCAM2		0xf8
#define	GSTLC		0x100
#define GAFR		0x108
#define GHT1		0x110
#define	GHT2		0x118
#define GCFPT       0x120
#define GICFPT      0x128
#define GMACC3      0x130
#define GTIMR       0x138
#define GRIMR       0x140
#define GTSVREG     0x148
#define GRSVREG     0x150
#define GFSVREG     0x158
#define	GRFIC1		0x180
#define	GRFIC2		0x188
#define	GRFIC3		0x190
#define	GTFIC1		0x198
#define	GTFIC2		0x1a0
#define	GUFCR		0x1a8

#define	GSTIR		0x7d8
#define	GMISCR		0x7e0
#define	GVERID		0x7f0
#define	GPOWD		0x7f8

#define	GR64		0x400
#define	GR127		0x408
#define	GR255		0x410
#define	GR511		0x418
#define	GR1K		0x420
#define	GRMAX		0x428
#define	GRMGV		0x430
#define	GRBYT		0x438
#define	GRPKT		0x440
#define	GRFCS		0x448
#define	GRMCA		0x450
#define	GRBCA		0x458
#define	GRXCF		0x460
#define	GRXPF		0x468
#define	GRXUO		0x470
#define	GRXLN		0x478
#define	GRFLR		0x480
#define	GRCDE		0x488
#define	GRCSE		0x490
#define	GRUND		0x498
#define	GROVR		0x4a0
#define	GRFRG		0x4a8
#define	GRJBR		0x4b0

#define	GT64C		0x500
#define	GT127C		0x508
#define	GT255C		0x510
#define	GT511C		0x518
#define	GT1KC		0x520
#define	GTMAXC		0x528
#define GTMGVC		0x530
#define GTBYTC		0x538
#define GTPKTC		0x540
#define GTMCAC		0x548
#define GTBCAC		0x550
#define GTXPFC		0x558
#define GTDFRC		0x560
#define GTEDFC		0x568
#define GTSCLC		0x570
#define GTMCLC		0x578
#define GTLCLC		0x580
#define GTXCLC		0x588
#define GTNCLC		0x590
#define GTDRPC		0x5a0
#define GTJBRC		0x5a8
#define GTFCSC		0x5b0
#define GTXCFC		0x5b8
#define GTOVRC		0x5c0
#define GTUNDC		0x5c8
#define GTFRGC		0x5d0

#define GRDRPC		0x600
#define GTFPEC		0x608

#define	GTX_CFGR 	0x800
#define	GTX_DPR	 	0x808
#define	GTX_DESCMON 0x810
#define	GTX_STSMON	0x818
#define	GTX_MBTSZ 	0x820
#define	GTX_SRST   	0x828
#define	GTX_ISR 	0x830
#define	GTX_MSR	 	0x838
#define	GTX_PERR 	0x840
#define	GTX_MPERR  	0x848
#define	GTX_ENMON  	0x850

#define	GRX_CFGR 	0x880
#define	GRX_DPR	 	0x888
#define	GRX_PDR	 	0x890
#define	GRX_PLALM  	0x898
#define	GRX_DESCMON 0x8a0
#define	GRX_STSMON	0x8a8
#define	GRX_MBTSZ 	0x8b0
#define	GRX_SRST   	0x8b8
#define	GRX_ISR 	0x8c0
#define	GRX_MSR	 	0x8c8
#define	GRX_PERR 	0x8d0
#define	GRX_MPERR  	0x8d8
#define	GRX_ENMON  	0x8e0
#define	GRMII_SPD  	0x8e8

#define	GDMATIM 	0x900
#define	GPFTIM		0x908
#define	GSLV_PERR  	0x910
#define GSLV_MPERR 	0x918
#define GIODRSTR 	0x920

/***********************************************************************
 * debug
 ***********************************************************************
 */

#define		DEBUG_NEC_CANDY
// #define		DEBUG_VERBOSE_NEC_CANDY
// #define	SHOW_BUG		/* targeted bug reporting msgs */

#ifdef DEBUG_VERBOSE_NEC_CANDY
#define DEBUG_NEC_CANDY
#endif

#ifdef DEBUG_NEC_CANDY

#define ASSERT(x) if (!(x)) { panic("%s:%d - assert failed!\n", __FILE__, __LINE__); }
#define VERIFY(x, y) ASSERT(x y)
#define DEBUG(x)  do { x; } while (0)

#else

#define ASSERT(x)
#define VERIFY(x, y) x
#define DEBUG(x)

#endif

#ifdef DEBUG_VERBOSE_NEC_CANDY
#define DEBUG_VERBOSE(x)  do { x; } while (0)
#else
#define DEBUG_VERBOSE(x)
#endif

/***********************************************************************
 * Configure 
 ***********************************************************************
 */
/*
 * This driver supports multiple nec_candy chips.
 */
#define		MAX_NUM_DEVS		2

/* the maximum poll times for waiting on a register */
/* Autonegotiations may take up to 1/2 seconds. Status polled every
   microseconds; 500000 corresponds to the waiting at least 1/2 seconds */
#define		MAX_POLL_TIMES		500000

#define		TX_RING_SIZE		32
#define		RX_RING_SIZE		32

#define		RX_BUF_SIZE		1536
#define		ETH_FRAME_SIZE		1536

#define		TX_TIMEOUT		4*HZ

/* rx_copybreak:  for smaller packet we copy them to avoid emulated
 * unaligned access overhead.
 *
 * Set it to 1518 to always copy ( you should do that on fast machines)
 *
 * Set it to 0 to avoid any copy.
 *
 * On Korva, some value in the middle might be appropriate.
 */
// static int rx_copybreak=1518;

/*---------------------------------------------------------------------------*/
/* PHY link status                                                           */
/*---------------------------------------------------------------------------*/
#define LINK_UP     1
#define LINK_DOWN   0

/*---------------------------------------------------------------------------*/
/* receive mode & related definitions                                        */
/*---------------------------------------------------------------------------*/
#define ACCEPT_ALL_PHYS         0x0001
#define ACCEPT_ALL_MCASTS       0x0002
#define ACCEPT_ALL_BCASTS       0x0004
#define ACCEPT_QUALIFIED_MCAST  0x0008
#define ACCEPT_STATION          0x0010
#define MAC_LOOPBACK            0x0020

/*---------------------------------------------------------------------------*/
/* MACC1 - MAC configuration register 1 (00H R/W)                            */
/*---------------------------------------------------------------------------*/
#define MACLB       0x00004000      /* MAC loopback                          */
#define TXFC        0x00000800      /* Transmit flow control enable          */
#define RXFC        0x00000400      /* Receive flow control enable           */
#define SRXEN       0x00000200      /* Receive enable                        */
#define PARF        0x00000100      /* Control packet pass                   */
#define PUREP       0x00000080      /* Pure preamble                         */
#define FLCHT       0x00000040      /* Length field check                    */
#define NOBO        0x00000020      /* No Back Off                           */
#define CRCEN       0x00000008      /* CRC append enable                     */
#define PADEN       0x00000004      /* PAD append enable                     */
#define FULLD       0x00000002      /* Full duplex enable                    */
#define HUGEN       0x00000001      /* Large packet enable                   */
#define MACC1_RESERVED  0x00004fef  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* MACC2 - MAC configuration register 2 (04H R/W)                            */
/*---------------------------------------------------------------------------*/
#define MCRST       0x00000400      /* MAC Control Block software reset      */
#define RFRST       0x00000200      /* Receive Function Block software reset */
#define TFRST       0x00000100      /* Transmit Function Block software reset*/
#define BPNB        0x00000040      /* Back Pressure No Back Off             */
#define APD         0x00000020      /* Auto VLAN PAD                         */
#define VPD         0x00000010      /* VLAN PAD mode                         */
#define MACC2_RESERVED  0x00000770  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* IPGT - Back-to-Back IPG register (08H R/W)                                */
/*---------------------------------------------------------------------------*/
#define IPGT        0x00000013      /* Back-To-Back IPG default value        */
#define IPGT_RESERVED   0x0000007f  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* IPGR - Non Back-to-Back IPG register (0CH R/W)                            */
/*---------------------------------------------------------------------------*/
#define IPGR1       0x00000e00      /* Back-To-Back IPG default value        */
#define IPGR2       0x00000013      /* Back-To-Back IPG default value        */
#define IPGR_RESERVED   0x00007f7f  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* CLRT - Collision register (10H R/W)                                       */
/*---------------------------------------------------------------------------*/
#define LCOLW       0x00003800      /* Late collision window default value   */
#define RETRY       0x0000000f      /* Maximum number of retry default value */
#define CLRT_RESERVED   0x00003f0f  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* LMAX - Maximum Packet Length register (14H R/W)                           */
/*---------------------------------------------------------------------------*/
// #define MAXF        0x000005f2      /* Maximum packet length value(1522byte) */
#define MAXF        0x000005ee      /* Maximum packet length value(1518byte) */
#define LMAX_RESERVED   0x0000ffff  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* RETX - Retry count register (20H R/W)                                     */
/*---------------------------------------------------------------------------*/
#define RETX_MASK   0x0000000f      /* Retry counter                         */
#define RETX_RESERVED   0x0000000f  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* LSA2 - Station address register 2 (54H R/W)                               */
/*---------------------------------------------------------------------------*/
#define LSA2_MASK   0x0000ffff      /* Station address SA (47:32)            */
#define LSA2_RESERVED   0x0000ffff  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* LSA1 - Station address register 1 (58H R/W)                               */
/*---------------------------------------------------------------------------*/
#define LSA1_MASK   0xffffffff      /* Station address SA(31:0)              */

/*---------------------------------------------------------------------------*/
/* PTVR - Pause timer read register (5CH Read)                               */
/*---------------------------------------------------------------------------*/
#define PTCT_MASK   0x0000ffff      /* Pause timer counter                   */

/*---------------------------------------------------------------------------*/
/* VLTP - VLAN type register (64H R/W)                                       */
/*---------------------------------------------------------------------------*/
#define VLTP        0x00008100      /* VLAN type ( etpid:0x81 tci:0x00 )     */
#define VLTP_RESERVED   0x0000ffff  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* MIIC - MII Configuration register (80H R/W)                               */
/*---------------------------------------------------------------------------*/
#define MISRT       0x00008000      /* MII Management Interface Block software reset */
#define CLKS25      0x00000000      /* HCLK is equal to 25 MHz               */
#define CLKS33      0x00000004      /* HCLK is less than or equal to 33 MHz  */
#define CLKS50      0x00000008      /* HCLK is less than or equal to 50 MHz  */
#define CLKS66      0x0000000c      /* HCLK is less than or equal to 66 MHz  */
#define MIIC_RESERVED   0x0000800c  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* MCMD - MII command register (94H Write)                                   */
/*---------------------------------------------------------------------------*/
#define SCANC       0x00000002      /* SCAN command                          */
#define RSTAT       0x00000001      /* MII management read                   */

/*---------------------------------------------------------------------------*/
/* MADR - MII address register (98H R/W)                                     */
/*---------------------------------------------------------------------------*/
#define FIAD_MASK   0x00001f00      /* MII PHY address                       */
#define FIAD_SHIFT  8
#define RGAD_MASK   0x0000001f      /* MII register address                  */
#define MADR_RESERVED   0x00001f1f  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* MWTD - MII write data register  (9CH R/W)                                 */
/*---------------------------------------------------------------------------*/
#define CTLD_MASK   0x0000ffff      /* MII write data                        */
#define MWTD_RESERVED   0x0000ffff  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* MRDD - MII read data register (A0H Read)                                  */
/*---------------------------------------------------------------------------*/
#define PRSD_MASK   0x0000ffff      /* MII read data                         */

/*---------------------------------------------------------------------------*/
/* MIND - MII indicator register (A4H Read)                                  */
/*---------------------------------------------------------------------------*/
#define NVALID      0x00000004      /* SCAN command start status             */
#define SCANA       0x00000002      /* SCAN command active                   */
#define BUSY        0x00000001      /* BUSY                                  */

/*---------------------------------------------------------------------------*/
/* STLC - STL configuration register (C0H R/W)                               */
/*---------------------------------------------------------------------------*/
#define ATZ         0x00000004      /* Statistics counter read reset         */
#define STLC_RESERVED   0x00000004  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* AFR - Address Filter register (C8H R/W)                                   */
/*---------------------------------------------------------------------------*/
#define PRO         0x00000008      /* Promiscuous mode                      */
#define PRM         0x00000004      /* Accept Multicast                      */
#define AMC         0x00000002      /* Accept Multicast ( qualified )        */
#define ABC         0x00000001      /* Accept Broadcast                      */
#define AFR_RESERVED    0x0000000f  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* CAR1 - CARRY register1 (DCH R/W)                                          */
/*---------------------------------------------------------------------------*/
#define C1VT        0x00008000      /* RVBT counter carry bit                */
#define C1UT        0x00004000      /* TUCA counter carry bit                */
#define C1BT        0x00002000      /* TBCA counter carry bit                */
#define C1MT        0x00001000      /* TMCA counter carry bit                */
#define C1PT        0x00000800      /* TPCT counter carry bit                */
#define C1TB        0x00000400      /* TBYT counter carry bit                */
#define C1MX        0x00000200      /* RMAX counter carry bit                */
#define C11K        0x00000100      /* R1K counter carry bit                 */
#define C1FE        0x00000080      /* R511 counter carry bit                */
#define C1TF        0x00000040      /* R255 counter carry bit                */
#define C1OT        0x00000020      /* R127 counter carry bit                */
#define C1SF        0x00000010      /* R64 counter carry bit                 */
#define C1BR        0x00000008      /* RBCA counter carry bit                */
#define C1MR        0x00000004      /* RBCA counter carry bit                */
#define C1PR        0x00000002      /* RPKT counter carry bit                */
#define C1RB        0x00000001      /* RBYT counter carry bit                */
#define CAR1_RESERVED   0x0000ffff  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* CAR2 - CARRY register2 (E0H R/W)                                          */
/*---------------------------------------------------------------------------*/
#define C2SV        0x80000000      /* Status vector overrun bit             */
#define C2IM        0x00400000      /* TIME counter carry bit                */
#define C2CS        0x00200000      /* TCSE counter carry bit                */
#define C2BC        0x00100000      /* TNCL counter carry bit                */
#define C2XC        0x00080000      /* TXCL counter carry bit                */
#define C2LC        0x00040000      /* TLCL counter carry bit                */
#define C2MC        0x00020000      /* TMCL counter carry bit                */
#define C2SC        0x00010000      /* TSCL counter carry bit                */
#define C2XD        0x00008000      /* TXDF counter carry bit                */
#define C2DF        0x00004000      /* TDFR counter carry bit                */
#define C2XF        0x00002000      /* TXPF counter carry bit                */
#define C2TE        0x00001000      /* TFCS counter carry bit                */
#define C2JB        0x00000800      /* RBJR counter carry bit                */
#define C2FG        0x00000400      /* RFRG counter carry bit                */
#define C2OV        0x00000200      /* ROVR counter carry bit                */
#define C2UN        0x00000100      /* RUND counter carry bit                */
#define C2FC        0x00000080      /* RFCR counter carry bit                */
#define C2CD        0x00000040      /* RCDE counter carry bit                */
#define C2FO        0x00000020      /* RFLR counter carry bit                */
#define C2AL        0x00000010      /* RALN counter carry bit                */
#define C2UO        0x00000008      /* RXUO counter carry bit                */
#define C2PF        0x00000004      /* RXPF counter carry bit                */
#define C2CF        0x00000002      /* RXCF counter carry bit                */
#define C2RE        0x00000001      /* RFCS counter carry bit                */
#define CAR2_RESERVED   0x807fffff  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* TXCFG - Transmit Configuration (200H R/W)                                 */
/*---------------------------------------------------------------------------*/
#define AFCE        0x00000001      /* Automatic Flow Control Enable         */
#define DTBS1       0x00000000      /* DMA Transmit Burst Size 1 word        */
#define DTBS2       0x00010000      /* DMA Transmit Burst Size 2 word        */
#define DTBS4       0x00020000      /* DMA Transmit Burst Size 4 word        */
#define DTBS8       0x00030000      /* DMA Transmit Burst Size 8 word        */
#define DTBS16      0x00040000      /* DMA Transmit Burst Size 16 word       */
#define DTBS32      0x00050000      /* DMA Transmit Burst Size 32 word       */
#define DTBS64      0x00060000      /* DMA Transmit Burst Size 64 word       */
#define TXE         0x80000000      /* Transmit Enable                       */
#define TXCFG_RESERVED  0x80070001  /* reserved bit                          */

/*---------------------------------------------------------------------------*/
/* TXFC - Transmit FiFo Control (204H R/W)                                   */
/*---------------------------------------------------------------------------*/
#define TPTV_MASK       0xffff0000  /* Transmit Pause Timer Value mask       */
#define TPTV            0x10000000  /* default 0x1000 slot time (1slot:512bit) */
#define TPTV_aa55       0xaa550000  /* narimatsu setting value */
#define TX_DRTH_MASK    0x0000fc00  /* Transmit Fill Threshold Level mask    */
#define TX_DRTH         0x00004000  /* default 010000b (16word, 64byte)      */
#define TX_DRTH8W       0x00002000  /* default 001000b (8word, 32byte)      */
#define TX_FLTH_MASK    0x000000fc  /* Transmit Drain Threshold Level mask   */
#define TX_FLTH         0x000000c0  /* default 110000b (48word, 192byte)     */
#define TX_FLTH128B     0x00000080  /* 100000b (128byte)     */
#define TXFC_RESERVED   0xfffffcfc  /* reserved bit                          */

/*---------------------------------------------------------------------------*/
/* TXST - Transmit Status  (20CH R)                                          */
/*---------------------------------------------------------------------------*/
#define CSE_AB      0x80000000  /* carrier lost (abort)                      */
#define TBP         0x40000000  /* back pressure occurred                    */
#define TPP         0x20000000  /* packet requested during PAUSE             */
#define TPCF        0x10000000  /* transmit PAUSE control frame              */
#define TCFR        0x08000000  /* transmit control frame                    */
#define TUDR_AB     0x04000000  /* underrun (abort)                          */
#define TGNT_AB     0x02000000  /* greater than LMAX (abort)                 */
#define LCOL_AB     0x01000000  /* late collision  (abort)                   */
#define ECOL_AB     0x00800000  /* excessive collisions (abort)              */
#define TEDFR_AB    0x00400000  /* excessive defer (abort)                   */
#define TDFR        0x00200000  /* single defer                              */
#define TBRO        0x00100000  /* broadcast packet                          */
#define TMUL        0x00080000  /* multicast packet                          */
#define TDONE       0x00040000  /* transmit complete                         */
#define TFLOR       0x00020000  /* length field  was over 1518 bytes         */
#define TFLER       0x00010000  /* length field didn't match actual length   */
#define TCRCE       0x00008000  /* CRC error                                 */
#define TCBC_MASK   0x00007800  /* number of collisions                      */
#define TBYT_MASK   0x000007ff  /* number of the transmitted bytes           */

/*---------------------------------------------------------------------------*/
/* RXCFG - Receive Configuration (218H R/W)                                  */
/*---------------------------------------------------------------------------*/
#define DRBS1       0x00000000      /* DMA Receive Burst Size 1 word         */
#define DRBS2       0x00010000      /* DMA Receive Burst Size 2 word         */
#define DRBS4       0x00020000      /* DMA Receive Burst Size 4 word         */
#define DRBS8       0x00030000      /* DMA Receive Burst Size 8 word         */
#define DRBS16      0x00040000      /* DMA Receive Burst Size 16 word        */
#define DRBS32      0x00050000      /* DMA Receive Burst Size 32 word        */
#define DRBS64      0x00060000      /* DMA Receive Burst Size 64 word        */
#define RXE         0x80000000      /* Receive Enable                        */
#define RXCFG_RESERVED  0x80070000  /* reserved bit                          */

/*---------------------------------------------------------------------------*/
/* RXFC - Receive FiFo Control (21CH R/W)                                    */
/*---------------------------------------------------------------------------*/
#define UWM_MASK        0xfc000000      /* Upper Water Mark mask             */
#define UWM             0xc0000000      /* default 110000b ( 48word, 192byte ) */
#define LWM_MASK        0x00fc0000      /* Lower Water Mark mask             */
#define LWM             0x00400000      /* default 010000b (16word, 64byte)  */
#define RX_DRTH_MASK    0x000000fc      /* Receive Drain Threshold Level     */
#define RX_DRTH8W       0x00000020      /* default 001000b (8word, 32byte)  */
#define RX_DRTH16W      0x00000040      /* default 010000b (16word, 64byte)  */
#define RX_DRTH28W      0x00000070      /* default 011100b (28word, 112byte) */
#define RXFC_RESERVED   0xfcfc00fc      /* reserved bit                      */

/*---------------------------------------------------------------------------*/
/* RXST - Receive Status (224H R)                                            */
/*---------------------------------------------------------------------------*/
#define RLENE       0x80000000      /* less than 64 or larger than 1518      */
#define VLAN        0x40000000      /*  match VLTP                           */
#define USOP        0x20000000      /* unknown OP code control frame         */
#define RPCF        0x10000000      /* receive PAUSE control frame           */
#define RCFR        0x08000000      /* receive control frame                 */
#define DBNB        0x04000000      /* alignment error                       */
#define RBRO        0x02000000      /* broadcast packet                      */
#define RMUL        0x01000000      /* multicast packet                      */
#define RX_OK       0x00800000      /* receive OK                            */
#define RLOR        0x00400000      /* length field was over 1518 bytes      */
#define RLER        0x00200000      /* length field didn't match actual length */
#define RCRCE       0x00100000      /* CRC error                             */
#define RCVE        0x00080000      /* RXER was detected (PHY error)         */
#define CEPS        0x00040000      /* false Carrier                         */
#define REPS        0x00020000      /* preamble+SFD or +one data nibble      */
#define PAIG        0x00010000      /* carrier length 3036 octets
				                                    or Short IPG or invalid preamble or invalid SFD */
#define RBYT_MASK   0x0000ffff      /* received byte count                   */

/*---------------------------------------------------------------------------*/
/* RXPD - Receive Pool Descriptor (230H R/W)                                 */
/*---------------------------------------------------------------------------*/
#define AL          0x70000000      /* Alert Level default value             */
#define AL_MASK     0x70000000
#define RNOD_MASK   0x0000ffff      /* Remaining Number of Descriptor        */
#define RXPD_RESERVED   0x7000ffff  /* reserved bit                          */

/*---------------------------------------------------------------------------*/
/* CCR - Candy Configuration Register (234H R / 240H W)                      */
/*---------------------------------------------------------------------------*/
#define SRT         0x00000001      /* Candy Software Reset                  */

/*---------------------------------------------------------------------------*/
/* ISR - Interrupt Serves Register (238H R with clear)                       */
/* MSR - Mask Serves Register      (23cH R/W)                                */
/*---------------------------------------------------------------------------*/
#define BUSERR      0x80000000  /* IBUS Error                                */
#define XMTDN       0x00008000  /* Transmit Done                             */
#define TBDR        0x00004000  /* Transmit Buffer Descriptor Request at Null*/
#define TFLE        0x00002000  /* Transmit Frame Length Exceed              */
#define UR          0x00001000  /* Underrun                                  */
#define TABR        0x00000800  /* Transmit Aborted                          */
#define TCF         0x00000400  /* Transmit Control Frame                    */
#define RCVDN       0x00000080  /* Receive Done                              */
#define RBDRS       0x00000040  /* Receive Buffer Descriptor Request at alert level */
#define RBDRU       0x00000020  /* Receive Buffer Descriptor Request at zero */
#define OF          0x00000010  /* Overflow                                  */
#define LFAL        0x00000008  /* Link Failed                               */
#define CARRY       0x00000001  /* statistics counters carry flag            */
#define ISR_RESERVED    0x8000fcf9  /* reserved bit                          */

#define INT_ISR_TX_MASK         0x0000FC00      /* ISR TX bits mask */
#define INT_ISR_RX_MASK         0x000000F0      /* ISR RX bits mask */


/* add for Arcadia */
/*---------------------------------------------------------------------------*/
/* GMACC1 - MAC configuration register 1 (000H R/W)                          */
/*---------------------------------------------------------------------------*/
#define GSRST        0x80000000      /* Soft reset                           */
#define GRMCRST      0x00080000      /* MAC receive control soft reset       */
#define GTMCRST      0x00040000      /* MAC transmit control soft reset      */
#define GRFRST       0x00020000      /* MAC receive soft reset               */
#define GTFRST       0x00010000      /* MAC transmit soft reset              */
#define GLPBK        0x00000100      /* Loopback                             */
#define GRFCEN       0x00000020      /* Receive flow control enable          */
#define GTFCEN       0x00000010      /* Transmit flow control enable         */
#define GREN         0x00000004      /* Receive enable                       */
#define GTEN         0x00000001      /* Transmit enable                      */
#define GMACC1_RESERVED  0x800f0135  /* reserved bit 0                       */

/*---------------------------------------------------------------------------*/
/* GMACC2 - MAC configuration register 2 (008H R/W)                          */
/*---------------------------------------------------------------------------*/
#define GPRELN       0x00007000      /* Preamble length                      */
#define GIFMOD       0x00000200      /* Interface mode                       */
#define GIFMOD_4     0x00000100      /* Interface mode(nible)                */
#define GRMIIM       0x00000080      /* RMII mode                            */
#define GHUGEN       0x00000020      /* Large packet enable                  */
#define GLENCK       0x00000010      /* Length field check                   */
#define GPADEN       0x00000004      /* PAD append enable                    */
#define GCRCEN       0x00000002      /* CRC append enable                    */
#define GFULLD       0x00000001      /* Full duplex enable                   */
#define GMACC2_RESERVED  0x000072b7  /* reserved bit 0                       */

/*---------------------------------------------------------------------------*/
/* GIPGIFG - IPG / IFG register (010H R/W)                                   */
/*---------------------------------------------------------------------------*/
#define GIPGR1       0x40000000      /* Non-Back-To-Back IPG default value   */
#define GIPGR2       0x00600000      /* Non-Back-To-Back IPG default value   */
#define GMINIFG      0x00005000      /* Minimum IFG default value            */
#define GIPGT        0x00000060      /* Back-To-Back IPG default value       */
#define GIPGIFG_RESERVED 0xefefffef  /* reserved bit 0                       */

/*---------------------------------------------------------------------------*/
/* GHDREG - Half duplex configuration register (018H R/W)                    */
/*---------------------------------------------------------------------------*/
#define GABEXT       0x00a00000      /* Alternate binary exponential backoff truncation default value */
#define GABEXE       0x00080000      /* Alterenate binary exponential backoff enable */
#define GBKPNB       0x00040000      /* Back pressure no backoff             */
#define GNBOF        0x00020000      /* No backoff                           */
#define GRTMAX       0x0000f000      /* Maximum number of retry default value*/
#define GCOLW        0x00000037      /* Collision window default value       */
#define GHDREG_RESERVED 0x00fef3ff   /* reserved bit 0                       */

/*---------------------------------------------------------------------------*/
/* GLMAX - Maximum flame Length register (020H R/W)                          */
/*---------------------------------------------------------------------------*/
//#define GMAXF        0x000005f2      /* Maximum packet length value(1522byte)*/
#define GMAXF        0x000005ee      /* Maximum packet length value(1518byte)*/
#define GLMAX_RESERVED   0x0000ffff  /* reserved bit 0                       */

/*---------------------------------------------------------------------------*/
/* GMIIC - MII Configuration register (040H R/W)                             */
/*---------------------------------------------------------------------------*/
#define GMISRT       0x80000000      /* MII Management Interface Block software reset */
#define GPRESUP      0x00000010      /* Preamble suppress                    */
#define GCLKS54      0x00000000
#define GCLKS54_     0x00000001
#define GCLKS68      0x00000002
#define GCLKS80      0x00000003
#define GCLKS108     0x00000004
#define GCLKS134     0x00000005
#define GCLKS160     0x00000006
#define GCLKS200     0x00000007
#define GMIIC_RESERVED   0x80000017  /* reserved bit 0                       */

/*---------------------------------------------------------------------------*/
/* GMCMD - MII command register (048H Write)                                 */
/*---------------------------------------------------------------------------*/
#define GSCANC       0x00000002      /* SCAN command                         */
#define GRSTAT       0x00000001      /* MII management read                  */

/*---------------------------------------------------------------------------*/
/* GMADR - MII address register (050H R/W)                                   */
/*---------------------------------------------------------------------------*/
#define GFIAD_MASK   0x00001f00      /* MII PHY address                      */
#define GFIAD_SHIFT  8
#define GRGAD_MASK   0x0000001f      /* MII register address                 */
#define GMADR_RESERVED   0x00001f1f  /* reserved bit 0                       */

/*---------------------------------------------------------------------------*/
/* GMWTD - MII write data register  (058H R/W)                               */
/*---------------------------------------------------------------------------*/
#define GCTLD_MASK   0x0000ffff      /* MII write data                       */
#define GMWTD_RESERVED   0x0000ffff  /* reserved bit 0                       */

/*---------------------------------------------------------------------------*/
/* GMRDD - MII read data register (060H Read)                                */
/*---------------------------------------------------------------------------*/
#define GPRSD_MASK   0x0000ffff      /* MII read data                        */

/*---------------------------------------------------------------------------*/
/* GMIND - MII indicator register (068H Read)                                */
/*---------------------------------------------------------------------------*/
#define GNVALID      0x00000004      /* SCAN command start status            */
#define GSCANA       0x00000002      /* SCAN command active                  */
#define GBUSY        0x00000001      /* BUSY                                 */

/*---------------------------------------------------------------------------*/
/* GPHYC - TBI PCS register access register (070H Read)                      */
/*---------------------------------------------------------------------------*/
#define GPHYC_RESERVED 0x0000001f    /* reserved bit 0                       */

/*---------------------------------------------------------------------------*/
/* GLSA1 - Station address register 1 (080H R/W)                             */
/*---------------------------------------------------------------------------*/
#define GLSA1_MASK   0xffffffff      /* Station address SA(31:0)             */

/*---------------------------------------------------------------------------*/
/* GLSA2 - Station address register 2 (088H R/W)                             */
/*---------------------------------------------------------------------------*/
#define GLSA2_MASK   0xffff0000      /* Station address SA (47:32)           */
#define GLSA2_RESERVED   0xffff0000  /* reserved bit 0                       */

/*---------------------------------------------------------------------------*/
/* GCAR1 - CARRY register1 (0E0H R/W)                                        */
/* GCAM1 - CARRY mast register1 (0F0H R/W)                                   */
/*---------------------------------------------------------------------------*/
#define GC1SF        0x80000000      /* R64 counter carry bit                */
#define GC1OT        0x40000000      /* R127 counter carry bit               */
#define GC1TF        0x20000000      /* R255 counter carry bit               */
#define GC1FE        0x10000000      /* R511 counter carry bit               */
#define GC11K        0x08000000      /* R1K counter carry bit                */
#define GC1MX        0x04000000      /* RMAX counter carry bit               */
#define GC1RMGV      0x02000000      /* RMGV counter carry bit               */
#define GC1RB        0x00010000      /* RBYT counter carry bit               */
#define GC1PR        0x00008000      /* RPKT counter carry bit               */
#define GC1RE        0x00004000      /* RFCS counter carry bit               */
#define GC1MR        0x00002000      /* RMCA counter carry bit               */
#define GC1BR        0x00001000      /* RBCA counter carry bit               */
#define GC1CF        0x00000800      /* RXCF counter carry bit               */
#define GC1PF        0x00000400      /* RXPF counter carry bit               */
#define GC1UO        0x00000200      /* RXUO counter carry bit               */
#define GC1AL        0x00000100      /* RALN counter carry bit               */
#define GC1FO        0x00000080      /* RFLR counter carry bit               */
#define GC1CD        0x00000040      /* RCDE counter carry bit               */
#define GC1RCS       0x00000020      /* RCSE counter carry bit               */
#define GC1UN        0x00000010      /* RUND counter carry bit               */
#define GC1OV        0x00000008      /* ROVR counter carry bit               */
#define GC1FG        0x00000004      /* RFRG counter carry bit               */
#define GC1RJB       0x00000002      /* RJBR counter carry bit               */
#define GC1RDR       0x00000001      /* RDRP counter carry bit               */
#define GCAR1_RESERVED 0xfe01ffff    /* reserved bit 0                       */

/*---------------------------------------------------------------------------*/
/* GCAR2 - CARRY register2 (0E8H R/W)                                        */
/* GCAM2 - CARRY mask register2 (0F8H R/W)                                   */
/*---------------------------------------------------------------------------*/
#define GC2SF        0x80000000      /* T64 counter carry bit                */
#define GC2OT        0x40000000      /* T127 counter carry bit               */
#define GC2TF        0x20000000      /* T255 counter carry bit               */
#define GC2FE        0x10000000      /* T511 counter carry bit               */
#define GC21K        0x08000000      /* T1K counter carry bit                */
#define GC2MX        0x04000000      /* TMAX counter carry bit               */
#define GC2RMGV      0x02000000      /* TMGV counter carry bit               */
#define GC2TPAR      0x00100000      /* TFPE counter carry bit               */
#define GC2RJB       0x00080000      /* TJBR counter carry bit               */
#define GC2TE        0x00040000      /* TFCS counter carry bit               */
#define GC2TCF       0x00020000      /* TXCF counter carry bit               */
#define GC2TOV       0x00010000      /* TOVR counter carry bit               */
#define GC2TUN       0x00008000      /* TUND counter carry bit               */
#define GC2TFG       0x00004000      /* TFRG counter carry bit               */
#define GC2TB        0x00002000      /* TBYT counter carry bit               */
#define GC2TPK       0x00001000      /* TPKT counter carry bit               */
#define GC2MT        0x00000800      /* TMCA counter carry bit               */
#define GC2BT        0x00000400      /* TBCA counter carry bit               */
#define GC2XF        0x00000200      /* TXPF counter carry bit               */
#define GC2DF        0x00000100      /* TDFR counter carry bit               */
#define GC2TED       0x00000080      /* TEDF counter carry bit               */
#define GC2SC        0x00000040      /* TSCL counter carry bit               */
#define GC2MC        0x00000020      /* TMCL counter carry bit               */
#define GC2LC        0x00000010      /* TLCL counter carry bit               */
#define GC2XC        0x00000008      /* TXCL counter carry bit               */
#define GC2BC        0x00000004      /* TNCL counter carry bit               */
#define GC2TDP       0x00000001      /* TDRP counter carry bit               */
#define GCAR2_RESERVED   0xfe1ffffd  /* reserved bit 0                       */

/*---------------------------------------------------------------------------*/
/* GSTLC - STL configuration register (100H R/W)                             */
/*---------------------------------------------------------------------------*/
#define GATZ         0x00000004      /* Statistics counter read reset        */
#define GSTRST       0x00000001      /* Statistics counter soft reset        */
#define GSTLC_RESERVED   0x00000005  /* reserved bit 0                       */

/*---------------------------------------------------------------------------*/
/* GAFR - Address Filter register (108H R/W)                                 */
/*---------------------------------------------------------------------------*/
#define GPRO         0x00000010      /* Promiscuous mode                     */
#define GAUC         0x00000008      /* Accept Unicast                       */
#define GPRM         0x00000004      /* Accept Multicast                     */
#define GAMC         0x00000002      /* Accept Multicast ( qualified )       */
#define GABC         0x00000001      /* Accept Broadcast                     */
#define GAFR_RESERVED    0x0000001f  /* reserved bit 0                       */


/*---------------------------------------------------------------------------*/
/* GHT1 - Hash Table 1 (110H R/W)                                            */
/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/
/* GHT2 - Hash Table 2 (118H R/W)                                            */
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/* GCFPT - MACC pause value set register (120H Read)                         */
/*---------------------------------------------------------------------------*/
#define GCFPT_MASK   0x0000ffff      /* Pause timer counter                  */

/*---------------------------------------------------------------------------*/
/* GICFPT - Internal Pause timer register (128H Read)                        */
/*---------------------------------------------------------------------------*/
#define GICFPT_MASK   0x0000ffff      /* Pause timer counter                 */

/*---------------------------------------------------------------------------*/
/* GMACC3 - MAC configuration register 3 (0130H R/W)                         */
/*---------------------------------------------------------------------------*/
#define GAPSE        0x00000040      /* Status Info append(tail)             */
#define GAPSS        0x00000020      /* Status Info append(head)             */
#define GBACKPE      0x00000008      /* Back pressure enable                 */
#define GFLWCNT      0x00000004      /* Transmit flow control enable         */
#define GTXFFLH      0x00000002      /* Transmit FIFO flush                  */
#define GRXFFLH      0x00000001      /* Receive FIFO flush                   */
#define GMACC3_RESERVED  0x0000006f  /* reserved bit 0                       */

/*---------------------------------------------------------------------------*/
/* GTIMR - Transmit interrupt mask register  (138H R)                        */
/*---------------------------------------------------------------------------*/
#define GTPER        0x00080000  /* FIFO parity error                        */
#define GTFOV        0x00040000  /* FIFO over run                            */
#define GTFUN        0x00020000  /* FIFO under run                           */
#define GTWMH        0x00010000  /* FIFO full level over                     */
#define GTVLTF       0x00008000  /* VLAN frame send                          */
#define GTBP         0x00004000  /* back pressure occurred                   */
#define GTPCF        0x00002000  /* transmit PAUSE control frame             */
#define GTCFR        0x00001000  /* transmit control frame                   */
#define GTUDR_AB     0x00000800  /* underrun (abort)                         */
#define GTGNT_AB     0x00000400  /* greater than LMAX (abort)                */
#define GLCOL_AB     0x00000200  /* late collision  (abort)                  */
#define GECOL_AB     0x00000100  /* excessive collisions (abort)             */
#define GTEDFR_AB    0x00000080  /* excessive defer (abort)                  */
#define GTDFR        0x00000040  /* single defer                             */
#define GTBRO        0x00000020  /* broadcast packet                         */
#define GTMUL        0x00000010  /* multicast packet                         */
#define GTDONE       0x00000008  /* transmit complete                        */
#define GTFLOR       0x00000004  /* length field  was over 1518 bytes        */
#define GTFLER       0x00000002  /* length field didn't match actual length  */
#define GTCRCE       0x00000001  /* CRC error                                */
#define GTIMR_RESERVED  0x000fffff  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* GRIMR - Receive interrupt mask register  (140H R)                        */
/*---------------------------------------------------------------------------*/
#define GRFOV        0x00080000      /* FIFO over run                        */
#define GRWMH        0x00040000      /* Pause frame transmit level           */
#define GRWML        0x00020000      /* Zero frame transmit level            */
#define GVLAN        0x00004000      /* VLAN frame                           */
#define GUSOP        0x00002000      /* unknown OP code control frame        */
#define GRPCF        0x00001000      /* receive PAUSE control frame          */
#define GRCFR        0x00000800      /* receive control frame                */
#define GDBNB        0x00000400      /* alignment error                      */
#define GRBRO        0x00000200      /* broadcast packet                     */
#define GRMUL        0x00000100      /* multicast packet                     */
#define GRX_OK       0x00000080      /* receive OK                           */
#define GRLOR        0x00000040      /* length field was over 1518 bytes     */
#define GRLER        0x00000020      /* length field didn't match actual length */
#define GRCRCE       0x00000010      /* CRC error                            */
#define GRCVE        0x00000008      /* RXER was detected (PHY error)        */
#define GRFCA        0x00000004      /* false Carrier                        */
#define GREPS        0x00000002      /* preamble+SFD or +one data nibble     */
#define GRPPD        0x00000001      /* ignore receive packet                */
#define GRIMR_RESERVED  0x000e7fff  /* reserved bit 0                        */

/*---------------------------------------------------------------------------*/
/* GTSVREG - Tx Status register (148H R/W)                                   */
/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/
/* GRSVREG - Rx Status register (150H R/W)                                   */
/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/
/* GFSVREG - FIFO Status register (158H R/W)                                 */
/*---------------------------------------------------------------------------*/
#define GFTPER        0x00010000     /* Transmit FIFO parity error           */
#define GFTFOV        0x00000400     /* Transmit FIFO over run               */
#define GFTFUN        0x00000200     /* Transmit FIFO under run              */
#define GFTWMH        0x00000100     /* Transmit full level over             */
#define GFRFOV        0x00000004     /* Receive FIFO over flow               */
#define GFRWMH        0x00000002     /* Pause frame transmit level over      */
#define GFRWML        0x00000001     /* Zero frame transmit level over       */

/*---------------------------------------------------------------------------*/
/* GRFIC1 - Rx FIFO Configuration register (180H R/W)                        */
/*---------------------------------------------------------------------------*/
#define GRFWMH_MASK      0x1fff0000      /* Pause frame Tx level mask        */
#define GRFWMH           0x17ff0000      /* default                          */
#define GRFWML_MASK      0x00001fff      /* Zero frame Tx level mask         */
#define GRFWML           0x00000000      /* default                          */
#define GRFIC1_RESERVED  0x1fff1fff      /* reserved bit                     */

/*---------------------------------------------------------------------------*/
/* GRFIC2 - Rx FIFO Configuration register (188H R/W)                        */
/*---------------------------------------------------------------------------*/
#define GDDNB            0x00000008      /* dribble nibble discard           */
#define GSIFT            0x00000004      /* short packet discard             */
#define GDCRCE           0x00000002      /* CRC packet discard               */
#define GFCRX            0x00000001      /* Control packet discard           */
#define GRFIC2_RESERVED  0x0000000f      /* reserved bit                     */

/*---------------------------------------------------------------------------*/
/* GRFIC3 - Rx FIFO Configuration register (190H R/W)                        */
/*---------------------------------------------------------------------------*/
#define GTHRX_MASK       0x1fff0000      /* Rx complete threshold mask       */
#define GTHRX            0x1fff0000      /* default                          */
#define GRXETH_MASK      0x00001fff      /* Rx FIFO status disp mask         */
#define GRXETH           0x00001fff      /* default                          */
#define GRFIC3_RESERVED  0x1fff1fff      /* reserved bit                     */

/*---------------------------------------------------------------------------*/
/* GTFIC1 - Tx FIFO Configuration register (198H R/W)                        */
/*---------------------------------------------------------------------------*/
#define GTFWMH_MASK      0x1fff0000      /* Tx full level mask               */
#define GTFWMH           0x12000000      /* default                          */
#define GTFDWL_MASK      0x00001fff      /* Tx drain level mask              */
#define GTFDWL           0x00000600      /* default                          */
#define GTFIC1_RESERVED  0x1fff1fff      /* reserved bit                     */

/*---------------------------------------------------------------------------*/
/* GTFIC2 - Tx FIFO Configuration register (1A0H R/W)                        */
/*---------------------------------------------------------------------------*/
#define GDPAR            0x00000001      /* Tx FIFO Parity error abort       */
#define GTFIC2_RESERVED  0x00000001      /* reserved bit                     */

/*---------------------------------------------------------------------------*/
/* GUFCR - User Field Configuration register (1A8H R/W)                      */
/*---------------------------------------------------------------------------*/
#define GUFCR_RESERVED   0xffffffff      /* reserved bit                     */

/*---------------------------------------------------------------------------*/
/* GSTIR - Status Info register (7D8H R/W)                                   */
/*---------------------------------------------------------------------------*/
#define GP7TS            0x80000000
#define GP7RS            0x40000000
#define GP7FS            0x20000000
#define GP7CA            0x10000000
#define GP6TS            0x08000000
#define GP6RS            0x04000000
#define GP6FS            0x02000000
#define GP6CA            0x01000000
#define GP5TS            0x00800000
#define GP5RS            0x00400000
#define GP5FS            0x00200000
#define GP5CA            0x00100000
#define GP4TS            0x00080000
#define GP4RS            0x00040000
#define GP4FS            0x00020000
#define GP4CA            0x00010000
#define GP3TS            0x00008000
#define GP3RS            0x00004000
#define GP3FS            0x00002000
#define GP3CA            0x00001000
#define GP2TS            0x00000800
#define GP2RS            0x00000400
#define GP2FS            0x00000200
#define GP2CA            0x00000100
#define GP1TS            0x00000080
#define GP1RS            0x00000040
#define GP1FS            0x00000020
#define GP1CA            0x00000010
#define GP0TS            0x00000008
#define GP0RS            0x00000004
#define GP0FS            0x00000002
#define GP0CA            0x00000001
/*---------------------------------------------------------------------------*/
/* GMISCR - FIFO setting register (7E0H R/W)                                 */
/*---------------------------------------------------------------------------*/
#define GBUSMODE         0x04000000      /* 0:FIFO little_endian, 1:FIFO be  */
#define GPSEL            0x02000000      /* 0:FIFO even parity, 1:FIFO odd   */
#define GPEN             0x01000000      /* FIFO bus parity enable           */
#define GINTEN           0x00000100      /* Interrupt enable                 */
#define GSRRC            0x00000001      /* Status register read clear       */

/*---------------------------------------------------------------------------*/
/* GVERID - Version register (7F0H R/W)                                      */
/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/
/* GPOWD - Power down register (7F8H R/W)                                    */
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/* GTX_CFGR - Tx Configuration register (800H R/W)                           */
/*---------------------------------------------------------------------------*/
#define GTXE         0x80000000      /* Transmit Enable                      */

/*---------------------------------------------------------------------------*/
/* GTX_DPR - Tx DESC Pointer register (809H R/W)                             */
/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/
/* GTX_DESCMON - Tx DESC Pointer Monitor register (810H R/W)                 */
/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/
/* GTX_STSMON - Tx DMA State Monitor register (818H R/W)                     */
/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/
/* GTX_SRST - Tx DMA soft reset register (828H R/W)                          */
/*---------------------------------------------------------------------------*/
#define GTXRST       0x00000001      /* Transmit DMA reset                   */

/*---------------------------------------------------------------------------*/
/* GTX_ISR - Tx DMA ISR register (830H R/W)                                  */
/* GTX_MSR - Tx DMA MSR register (838H R/W)                                  */
/*---------------------------------------------------------------------------*/
#define GTXDRBUSERR  0x80000000  /* Tx DESC prefetch bus error               */
#define GTXDWBUSERR  0x40000000  /* Tx DESC writeback bus error              */
#define GTXDTBUSERR  0x20000000  /* Tx readdata bus error                    */
#define GTXDNDESC    0x00008000  /* Tx DESC Done                             */
#define GTXDESCNULL  0x00004000  /* Tx DESC Null link                        */
#define GTXEDEA      0x00002000  /* TXE deassert                             */
#define GTXHL        0x00001000  /* DMA health check                         */
#define GTXISR_RESERVED 0xe000f000

/*---------------------------------------------------------------------------*/
/* GTX_PERR - Tx Parity Error register (840H R/W)                            */
/* GTX_MPERR - Tx Parity Error Mask register (848H R/W)                      */
/*---------------------------------------------------------------------------*/
#define GTXMWPERR1   0x80000000  /* Master Wrapper Parity Error1             */
#define GTXMWPERR0   0x40000000  /* Master Wrapper Parity Error0             */

/*---------------------------------------------------------------------------*/
/* GTX_ENMON - Tx Enable Monitor register (850H R/W)                         */
/*---------------------------------------------------------------------------*/
#define GTXSTANDBY   0x00000002  /* Tx DMA Stand-by                          */
#define GTXTXEDEA    0x00000001  /* Tx DMA deassert                          */

/*---------------------------------------------------------------------------*/
/* GRX_CFGR - Rx Configuration register (880H R/W)                           */
/*---------------------------------------------------------------------------*/
#define GRXE         0x80000000      /* Receive Enable                       */

/*---------------------------------------------------------------------------*/
/* GRX_DPR - Rx DESC Pointer register (888H R/W)                             */
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/* GRX_DESCMON - Rx DESC Pointer Monitor register (8A0H R/W)                 */
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/* GRX_STSMON - Rx DMA State Monitor register (8A8H R/W)                     */
/*---------------------------------------------------------------------------*/
#define GRXDMAST_STANDBY   0x00000000
#define GRXDMAST_IDLE      0x00000001
#define GRXDMAST_DESCREAD  0x00000002
#define GRXDMAST_DMAREQ    0x00000003
#define GRXDMAST_DMAACK    0x00000004
#define GRXDMAST_EOFCHK    0x00000005
#define GRXDMAST_STAUSREAD 0x00000006
#define GRXDMAST_DESCWB    0x00000007
#define GRXDMAST_RXECHK    0x00000008
#define GRXDMAST_PAKFIN    0x00000009
#define GRXDMAST_CMDSTP    0x0000000A
#define GRXDMAST_DESCADSET 0x0000000B
#define GRXDMAST_FLASHBLK  0x0000000C
#define GRXDMAST_IRQGEN    0x0000000D
#define GRXDMAST_RXEDA     0x0000000E

/*---------------------------------------------------------------------------*/
/* GRX_PDR - Rx Pool DESC register (890H R/W)                                */
/*---------------------------------------------------------------------------*/
#define GRNOD_MASK   0x0000ffff      /* Remaining Number of Descriptor       */

/*---------------------------------------------------------------------------*/
/* GRX_PALAM - Rx Pool Alert register (898H R/W)                             */
/*---------------------------------------------------------------------------*/
#define GAL          0xf0000000      /* Alert Level default value            */
#define GAL_MASK     0xf0000000

/*---------------------------------------------------------------------------*/
/* GRX_MBTSZ - Rx DMA Burst Size register (8B0H R/W)                         */
/* GTX_MBTSZ - Rx DMA Burst Size register (820H R/W)                         */
/*---------------------------------------------------------------------------*/
#define GDMABST_64         0x00000000
#define GDMABST_32         0x00000001
#define GDMABST_16         0x00000002
#define GDMABST_8          0x00000003

/*---------------------------------------------------------------------------*/
/* GRX_SRST - Rx DMA Soft reset register (8B8H R/W)                          */
/*---------------------------------------------------------------------------*/
#define GMACRST      0x00000002      /* MAC core reset                       */
#define GRXRST       0x00000001      /* Receive DMA reset                    */

/*---------------------------------------------------------------------------*/
/* GRX_ISR - Rx DMA ISR register (8C0H R/W)                                  */
/* GRX_MSR - Rx DMA MSR register (8C8H R/W)                                  */
/*---------------------------------------------------------------------------*/
#define GRXDRBUSERR  0x80000000  /* Rx DESC prefetch bus error               */
#define GRXDWBUSERR  0x40000000  /* Rx DESC writeback bus error              */
#define GRXDTBUSERR  0x20000000  /* Rx writedata bus error                   */
#define GRXDNDESC    0x00008000  /* Rx DESC Done                             */
#define GRXDAL       0x00004000  /* Rx DESC alert                            */
#define GRXDZR       0x00002000  /* Rx DESC zero                             */
#define GRXEDEA      0x00001000  /* Rx RXE deassert                          */
#define GRXLFAL      0x00000800  /* Rx Link failed                           */
#define GRXHL        0x00000400  /* Rx DMA health check                      */
#define GRXISR_RESERVED 0xe000fc00

/*---------------------------------------------------------------------------*/
/* GRX_PERR - Rx Parity error register (8D0H R/W)                            */
/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/
/* GRX_MPERR - Rx Parity error mask register (8D8H R/W)                      */
/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/
/* GRX_ENMON - RXE deassert wait state monitor (8E0H R/W)                    */
/*---------------------------------------------------------------------------*/
#define GRXESTANDBY  0x00000002  /* Rx DMA stand-by                          */
#define GRXEWAIT     0x00000001  /* Rx RXE deassert                          */

/*---------------------------------------------------------------------------*/
/* GRMII_SPD - RMII interface mode register (8E8H R/W)                       */
/*---------------------------------------------------------------------------*/
#define GRMIISPD100  0x80000000  /* 0:100Mbps, 1:10Mbps                      */

/*---------------------------------------------------------------------------*/
/* MII register offsets                                                      */
/*---------------------------------------------------------------------------*/
#define     MII_CONTROL         0x0000
#define     MII_STATUS          0x0001
#define     MII_PHYID1          0x0002
#define     MII_PHYID2          0x0003
#define     MII_ANAR            0x0004
#define     MII_ANLPAR          0x0005
#define     MII_ANER            0x0006
#define     MII_GBSR            0x000a
#define     MII_LBREMR          0x0018
#define     MII_PAR             0x0019

/*---------------------------------------------------------------------------*/
/* MII Control register bit definitions.                                     */
/*---------------------------------------------------------------------------*/
#define     MIICNTL_SPEED1      0x0040
#define     MIICNTL_FDX         0x0100
#define     MIICNTL_RST_AUTO    0x0200
#define     MIICNTL_ISOLATE     0x0400
#define     MIICNTL_PWRDWN      0x0800
#define     MIICNTL_AUTO        0x1000
#define     MIICNTL_SPEED       0x2000
#define     MIICNTL_LPBK        0x4000
#define     MIICNTL_RESET       0x8000

/*---------------------------------------------------------------------------*/
/* MII Status register bit significance.                                     */
/*---------------------------------------------------------------------------*/
#define     MIISTAT_EXT         0x0001
#define     MIISTAT_JAB         0x0002
#define     MIISTAT_LINK        0x0004
#define     MIISTAT_CAN_AUTO    0x0008
#define     MIISTAT_FAULT       0x0010
#define     MIISTAT_AUTO_DONE   0x0020
#define     MIISTAT_CAN_T       0x0800
#define     MIISTAT_CAN_T_FDX   0x1000
#define     MIISTAT_CAN_TX      0x2000
#define     MIISTAT_CAN_TX_FDX  0x4000
#define     MIISTAT_CAN_T4      0x8000

/*---------------------------------------------------------------------------*/
/* MII ID2 register bits                                                     */
/*---------------------------------------------------------------------------*/
#define     MII_ID2_OUI_LO      0xFC00  /* low bits of OUI mask              */
#define     MII_ID2_MODEL       0x03F0  /* model number                      */
#define     MII_ID2_REV         0x000F  /* model number                      */

/*---------------------------------------------------------------------------*/
/* MII ANAR and ANLPAR register Bits                                         */
/*---------------------------------------------------------------------------*/
#define     MII_NWAY_NODE_SEL   0x001f
#define     MII_NWAY_CSMA_CD    0x0001
#define     MII_NWAY_T          0x0020
#define     MII_NWAY_T_FDX      0x0040
#define     MII_NWAY_TX         0x0080
#define     MII_NWAY_TX_FDX     0x0100
#define     MII_NWAY_T4         0x0200
#define     MII_NWAY_RF         0x2000
#define     MII_NWAY_ACK        0x4000
#define     MII_NWAY_NP         0x8000

/*---------------------------------------------------------------------------*/
/* MII Auto-Negotiation Expansion Register Bits                              */
/*---------------------------------------------------------------------------*/
#define     MII_ANER_PDF        0x0010
#define     MII_ANER_LP_NP_ABLE 0x0008
#define     MII_ANER_NP_ABLE    0x0004
#define     MII_ANER_RX_PAGE    0x0002
#define     MII_ANER_LP_AN_ABLE 0x0001

/*---------------------------------------------------------------------------*/
/* MII PAR register bit definitions.                                         */
/*---------------------------------------------------------------------------*/
#define     MIIPAR_DUPLEX       0x0080
#define     MIIPAR_SPEED        0x0040

/*---------------------------------------------------------------------------*/
/* MII GBSR register Bits                                                    */
/*---------------------------------------------------------------------------*/
#define     MII_NWAY_1000      0x0400
#define     MII_NWAY_1000_FDX  0x0800

/*---------------------------------------------------------------------------*/
/* Transmit/Receive Status bit definition in Transmit/Receive Descriptor     */
/*---------------------------------------------------------------------------*/
#define LAST        0x8000          /* Last Descriptor                       */
#define DB_LP       0x4000          /* Data Buffer / Link Pointer            */
#define OWN         0x2000          /* Owner 1:used by candy, 0:host set     */
/*---------------------------------------------------------------------------*/
/* Transmit Status bit definition in Transmit Descriptor                     */
/*---------------------------------------------------------------------------*/
#define DBRE        0x1000          /* Data Buffer Read Error                */
#define TUDR        0x0800          /* Transmit Underrun Error               */
#define CSE         0x0400          /* Carrier Sense Lost Error              */
#define LCOL        0x0200          /* Late Collision                        */
#define ECOL        0x0100          /* Excessive Collision                   */
#define EDFR        0x0080          /* Excessive Deferral                    */
#define TGNT        0x0004          /* Transmit Giant Frame                  */
#define HBF         0x0002          /* Heart Beat Fail for ENDEC mode        */
#define TOK         0x0001          /* Transmit OK                           */
/*---------------------------------------------------------------------------*/
/* Receive Status bit definition in Receive Descriptor (Candy)               */
/*---------------------------------------------------------------------------*/
#define DBWE        0x1000          /* Data Buffer Write Error               */
#define FTYP_MASK   0x0e00          /* Frame Type                            */
#define BCASTF      0x0000      	/* Broadcast Frame                       */
#define MCASTF      0x0200      	/* Multicast Frame                       */
#define UCASTF      0x0400      	/* Unicast Frame                         */
#define VLANF       0x0600      	/* VLAN Frame                            */
#define PAUSEF      0x0800      	/* PAUSE control Frame                   */
#define CTLF        0x0a00      	/* Control Frame                         */
#define OVRN        0x0100          /* Overrun Error                         */
#define RUNT        0x0080          /* Runt packet                           */
#define FRGE        0x0040          /* Fragment Error                        */
#define RCV         0x0020          /* Detects RXER                          */
#define FC          0x0010          /* False Carrier                         */
#define CRCE        0x0008          /* CRC Error                             */
#define FAE         0x0004          /* Frame Alignment Error                 */
#define RFLE        0x0002          /* Receive Frame Length Error            */
#define RXOK        0x0001          /* Receive OK                            */

/*---------------------------------------------------------------------------*/
/* Receive Status bit definition in Receive Descriptor (Arcadia)             */
/*---------------------------------------------------------------------------*/
#define G_RXOK      0x0004          /* Receive OK                          */

/**************************************************/
/*   UART                                         */
/**************************************************/
#define UART_1RBR		0xB8800C00	/* Receive buffer */
#define UART_1THR		0xB8800C00	/* Transmit buffer */
#define UART_1DLL		0xB8800C00	/* Baud Rate Clock Low */
#define UART_1IER	    0xB8800C02	/* Interrupt Enable Register */
#define UART_1DLM		0xB8800C02	/* Baud Rate Clock High */
#define UART_1IIR	    0xB8800C04	/* Interrupt ID Register */
#define UART_1FCR	    0xB8800C04	/* FIFO Control Register */
#define UART_1LCR	    0xB8800C06	/* Line Control Register */
#define UART_1MCR	    0xB8800C08	/* Modem Control Register */
#define UART_1LSR	    0xB8800C0A	/* Line Status Register */
#define UART_1MSR	    0xB8800C0C	/* Modem Status Register */
#define UART_1SCR	    0xB8800C0E	/* Scratch Register(for free use) */
#define UART_1RESET	    0xB8800C10	/* Reset Register */

#define UART_2RBR		0xB8800C40	/* Receive buffer */
#define UART_2THR		0xB8800C40	/* Transmit buffer */
#define UART_2DLL		0xB8800C40	/* Baud Rate Clock Low */
#define UART_2IER	    0xB8800C42	/* Interrupt Enable Register */
#define UART_2DLM		0xB8800C42	/* Baud Rate Clock High */
#define UART_2IIR	    0xB8800C44	/* Interrupt ID Register */
#define UART_2FCR	    0xB8800C44	/* FIFO Control Register */
#define UART_2LCR	    0xB8800C46	/* Line Control Register */
#define UART_2MCR	    0xB8800C48	/* Modem Control Register */
#define UART_2LSR	    0xB8800C4A	/* Line Status Register */
#define UART_2MSR	    0xB8800C4C	/* Modem Status Register */
#define UART_2SCR	    0xB8800C4E	/* Scratch Register(for free use) */
#define UART_2RESET	    0xB8800C50	/* Reset Register */

/**************** setting value *************************/

/*
 * These are the definitions for the FIFO Control Register
 */
#define UART_FCR_ENABLE_FIFO	0x01 /* Enable the FIFO */
#define UART_FCR_CLEAR_RCVR	0x02 /* Clear the RCVR FIFO */
#define UART_FCR_CLEAR_XMIT	0x04 /* Clear the XMIT FIFO */
#define UART_FCR_DMA_SELECT	0x08 /* For DMA applications */
#define UART_FCR_TRIGGER_MASK	0xF0 /* Mask for the FIFO trigger range */
#define UART_FCR_T_TRIGGER_0	0x00 /* Mask for transmit trigger set at 0 */
#define UART_FCR_T_TRIGGER_4	0x40 /* Mask for transmit trigger set at 4 */
#define UART_FCR_T_TRIGGER_8    0x80 /* Mask for transmit trigger set at 8 */
#define UART_FCR_T_TRIGGER_14	0xC0 /* Mask for transmit trigger set at 14 */

/*
 * These are the definitions for the Line Control Register
 */
#define UART_LCR_LCR7SET	0x80	/* Set LCR7 bit */
#define UART_LCR_SBC	0x40	/* Set break control */
#define UART_LCR_SPAR	0x20	/* Stick parity (?) */
#define UART_LCR_EPAR	0x10	/* Even parity select */
#define UART_LCR_PARITY	0x08	/* Parity Enable */
#define UART_LCR_STOP	0x04	/* Stop bits: 0=1 stop bit, 1= 2 stop bits */
#define UART_LCR_WLEN5  0x00	/* Wordlength: 5 bits */
#define UART_LCR_WLEN6  0x01	/* Wordlength: 6 bits */
#define UART_LCR_WLEN7  0x02	/* Wordlength: 7 bits */
#define UART_LCR_WLEN8  0x03	/* Wordlength: 8 bits */

/*
 * These are the definitions for the Line Status Register
 */
#define UART_LSR_TEMT	0x40	/* Transmitter empty */
#define UART_LSR_THRE	0x20	/* Transmit-hold-register empty */
#define UART_LSR_BI	0x10	/* Break interrupt indicator */
#define UART_LSR_FE	0x08	/* Frame error indicator */
#define UART_LSR_PE	0x04	/* Parity error indicator */
#define UART_LSR_OE	0x02	/* Overrun error indicator */
#define UART_LSR_DR	0x01	/* Receiver data ready */

/*
 * These are the definitions for the Interrupt Identification Register
 */
#define UART_IIR_NO_INT	0x01	/* No interrupts pending */
#define UART_IIR_ID	0x06	/* Mask for the interrupt ID */
#define UART_IIR_MSI	0x00	/* Modem status interrupt */
#define UART_IIR_THRI	0x02	/* Transmitter holding register empty */
#define UART_IIR_RDI	0x04	/* Receiver data interrupt */
#define UART_IIR_RLSI	0x06	/* Receiver line status interrupt */

/*
 * These are the definitions for the Interrupt Enable Register
 */
#define UART_IER_MSI	0x08	/* Enable Modem status interrupt */
#define UART_IER_RLSI	0x04	/* Enable receiver line status interrupt */
#define UART_IER_THRI	0x02	/* Enable Transmitter holding register int. */
#define UART_IER_RDI	0x01	/* Enable receiver data interrupt */

/*
 * These are the definitions for the Modem Control Register
 */
#define UART_MCR_LOOP	0x10	/* Enable loopback test mode */
#define UART_MCR_OUT2	0x08	/* Out2 complement */
#define UART_MCR_OUT1	0x04	/* Out1 complement */
#define UART_MCR_RTS	0x02	/* RTS complement */
#define UART_MCR_DTR	0x01	/* DTR complement */

/*
 * These are the definitions for the Modem Status Register
 */
#define UART_MSR_DCD	0x80	/* Data Carrier Detect */
#define UART_MSR_RI	0x40	/* Ring Indicator */
#define UART_MSR_DSR	0x20	/* Data Set Ready */
#define UART_MSR_CTS	0x10	/* Clear to Send */
#define UART_MSR_DDCD	0x08	/* Delta DCD */
#define UART_MSR_TERI	0x04	/* Trailing edge ring indicator */
#define UART_MSR_DDSR	0x02	/* Delta DSR */
#define UART_MSR_DCTS	0x01	/* Delta CTS */
#define UART_MSR_ANY_DELTA 0x0F	/* Any of the delta bits! */

/*
 * These are the definitions for the Reset Register
 */
#define UART_RESET_EN	0x01	/* UART Unit Reset Enable */
#define UART_RESET_DIS	0x00	/* UART Unit Reset disable */


/**************************************************/
/*   PCIX                                         */
/**************************************************/




#ifdef CONFIG_SOC_AU1500
/* Au1500 PCI Controller */
#define Au1500_CFG_BASE           0xB4005000 /* virtual, kseg0 addr */
#define Au1500_PCI_CMEM           (Au1500_CFG_BASE + 0)
#define Au1500_PCI_CFG            (Au1500_CFG_BASE + 4)
#define PCI_ERROR ((1<<22) | (1<<23) | (1<<24) | (1<<25) | (1<<26) | (1<<27))
#define Au1500_PCI_B2BMASK_CCH    (Au1500_CFG_BASE + 8)
#define Au1500_PCI_B2B0_VID       (Au1500_CFG_BASE + 0xC)
#define Au1500_PCI_B2B1_ID        (Au1500_CFG_BASE + 0x10)
#define Au1500_PCI_MWMASK_DEV     (Au1500_CFG_BASE + 0x14)
#define Au1500_PCI_MWBASE_REV_CCL (Au1500_CFG_BASE + 0x18)
#define Au1500_PCI_ERR_ADDR       (Au1500_CFG_BASE + 0x1C)
#define Au1500_PCI_SPEC_INTACK    (Au1500_CFG_BASE + 0x20)
#define Au1500_PCI_ID             (Au1500_CFG_BASE + 0x100)
#define Au1500_PCI_STATCMD        (Au1500_CFG_BASE + 0x104)
#define Au1500_PCI_CLASSREV       (Au1500_CFG_BASE + 0x108)
#define Au1500_PCI_HDRTYPE        (Au1500_CFG_BASE + 0x10C)
#define Au1500_PCI_MBAR           (Au1500_CFG_BASE + 0x110)

#define Au1500_PCI_HDR            0xB4005100 /* virtual, kseg0 addr */

/* All of our structures, like pci resource, have 32 bit members.
 * Drivers are expected to do an ioremap on the PCI MEM resource, but it's
 * hard to store 0x4 0000 0000 in a 32 bit type.  We require a small patch
 * to __ioremap to check for addresses between (u32)Au1500_PCI_MEM_START and
 * (u32)Au1500_PCI_MEM_END and change those to the full 36 bit PCI MEM
 * addresses.  For PCI IO, it's simpler because we get to do the ioremap
 * ourselves and then adjust the device's resources.
 */
#define Au1500_EXT_CFG            0x600000000
#define Au1500_EXT_CFG_TYPE1      0x680000000
#define Au1500_PCI_IO_START       0x500000000
#define Au1500_PCI_IO_END         0x5000FFFFF
#define Au1500_PCI_MEM_START      0x440000000
#define Au1500_PCI_MEM_END        0x443FFFFFF

#define PCI_IO_START    (Au1500_PCI_IO_START + 0x300)
#define PCI_IO_END      (Au1500_PCI_IO_END)
#define PCI_MEM_START   (Au1500_PCI_MEM_START)
#define PCI_MEM_END     (Au1500_PCI_MEM_END)
#define PCI_FIRST_DEVFN (0<<3)
#define PCI_LAST_DEVFN  (19<<3)

#endif

#if defined(CONFIG_SOC_AU1100) || (defined(CONFIG_SOC_AU1000) && !defined(CONFIG_MIPS_PB1000))
/* no PCI bus controller */
#define PCI_IO_START    0
#define PCI_IO_END      0
#define PCI_MEM_START   0
#define PCI_MEM_END     0
#define PCI_FIRST_DEVFN 0
#define PCI_LAST_DEVFN  0
#endif
#define AU1X_SOCK0_IO        0xF00000000
#define AU1X_SOCK0_PHYS_ATTR 0xF40000000
#define AU1X_SOCK0_PHYS_MEM  0xF80000000

/* pcmcia socket 1 needs external glue logic so the memory map
 * differs from board to board.
 */

/* Only for db board, not older pb */
#define AU1X_SOCK1_IO        0xF04000000
#define AU1X_SOCK1_PHYS_ATTR 0xF44000000
#define AU1X_SOCK1_PHYS_MEM  0xF84000000

#endif
